#!/usr/bin/env bash

matchesid="$@"
touch objectives.jsonl
next_week="$(date -d "$(echo ${PWD##*/}) +7days" +%Y%m%d)"
next_week_plus="$(date -d "$(echo ${PWD##*/}) +8days" +%Y%m%d)"
[[ -d "../$next_week" ]] &&
cp ../$next_week/matches.${next_week}* ../$next_week/matches.${next_week_plus}* ./
cp ../../guilds.jsonl guilds.jsonl
for match in $matchesid; do
  cleanse="$(grep -v '"'$match'"' objectives.jsonl)"
  echo "$cleanse" > objectives.jsonl
  mkdir $match
  [[ ${match%%-*} -eq 1 ]] && grepdate=$(date -d "$(echo ${PWD##*/}) 18:00 +1day-15hour" +%FT%TZ)
  [[ ${match%%-*} -eq 2 ]] && grepdate=$(date -d "$(echo ${PWD##*/}) 18:00" +%FT%TZ)
  pattern='"'$match'","start_time":"'$grepdate'"'
  for file in *.json; do
    echo jq $match $file
    grep $pattern $file -qs && jq '.[]|select(.id=="'$match'")' "$file" > "$match/$file";
  done
#  cd $match
#  for file in *.json; do
#    echo grep $match $file;
#    grep -qs "$grepdate" "$file" || echo $file >> rmfile
#  done
#  while read -r line; do
#    rm $line;
#  done < rmfile
#  rm rmfile
#  cd ..
done
objectives=$(
  for matchid in $matchesid; do
    cd $matchid
    grep '"claimed_at": "' -B5 * |
    sed 's/.*json.//' |
    grep -v 'id\|type\|flipped\|claimed_at' |
    tr -d '\n' |
    sed 's/--/\n/g' |
    sort |
    uniq --count |
    sort -h |
    sed 's/  */_/g' |
    sed 's/_/"count":/' |
    sed "s/_/,\"id\":\"$matchid\",/" |
    tr -d '_' |
    sed -E 's/(.*),(.*),(.*),(.*),/\2,\3,\4,\1/' |
    sed -E 's/(.*)claimedby(.*)/{\1guildid\2/'
    cd ..
  done |
  sort -t, -k1,1 -k2.11,2 -k4.9,4hr
)

for objective in $objectives; do
id=$(echo "$objective" | cut -d'"' -f4)
owner=$(echo "$objective" | cut -d'"' -f8)
guild=$(echo "$objective" | cut -d'"' -f12)
count=$(echo "$objective" | cut -d'"' -f15 | tr -d ' :}{,')

result=$(
grep "$guild" objectives.jsonl |
grep "\"owner\":\"$owner\"" |
grep "\"id\":\"$id\""
)

guildname=$(echo "$result" | cut -d'"' -f18)
guildtag=$(echo "$result" | cut -d'"' -f22)

if [ -z "$result" ]; then
printf '%s' "$objective" >> objectives.jsonl
if ! grep -q "$guild" guilds.jsonl; then
echo "New guild: https://api.guildwars2.com/v2/guild/$guild"
guildinfo=$(curl -s "https://api.guildwars2.com/v2/guild/$guild")
echo "$guildinfo" |
sed 's/^ *//' |
tr -d '\n' |
sed 's/": /":/g' |
sed 's/$/\n/' >> guilds.jsonl
fi
grep "$guild" guilds.jsonl |
sed 's/,"emblem.*/}/' |
sed 's/,"tag":"\(.*\)"}/}\1/' |
sed 's/,"name":"\(.*\)"}/}\1,/' |
sed 's/{"id":"\(.*\)"}/\1,/' |
sed 's/.*,\(.*\),\(.*\)/,"guildname":"\1","guildtag":"\2"}/' \
>> objectives.jsonl
else
resultcount=$(echo "$result" | cut -d'"' -f15 | tr -d ' :}{,')
newcount=$((resultcount + count))
newresult=$(printf '{"id":"%s","owner":"%s","guildid":"%s","count":%s,"guildname":"%s","guildtag":"%s"}' "$id" "$owner" "$guild" "$newcount" "$guildname" "$guildtag")
sed -i "s/$result/$newresult/g" objectives.jsonl || echo "DEBUG: $result"
fi
done

offensive=$(grep -Eav '{"id":"[12]-[1-6]","owner":"(Red|Blue|Green)","guildid":"[0-9A-F]{8}(-[0-9A-F]{4}){4}[0-9A-F]{8}","count":[0-9]+,"guildname":".*","guildtag":".*"}' objectives.jsonl)
if [ -n "$offensive" ]; then
{
echo
date -u -Is
echo "$offensive"
} >> objectives.offensive.log
grep -Ea '{"id":"[12]-[1-6]","owner":"(Red|Blue|Green)","guildid":"[0-9A-F]{8}-([0-9A-F]{4}-){3}[0-9A-F]{12}","count":[0-9]+,"guildname":".*","guildtag":".*"}' objectives.jsonl > objectives.sanitized.jsonl
mv "objectives.jsonl" "otherbak/objectives.bak$(date +%s).jsonl"
mv "objectives.sanitized.jsonl" "objectives.jsonl"
grep '{"id":.*}' "guilds.jsonl" > "guilds.sanitized.jsonl"
mv "guilds.jsonl" "otherbak/guilds.bak$(date +%s).jsonl"
mv "guilds.sanitized.jsonl" "guilds.jsonl"
fi

sortedguilds="$(sort -u guilds.jsonl)"
echo "$sortedguilds" > guilds.jsonl
cp guilds.jsonl ../../guilds.jsonl

rm matches.${next_week}* matches.${next_week_plus}*
